# Algorithms

## Base Response Mechanisms

- [dnsga2](algorithms/algorithms.base.dmoo.dnsga2.md)
- [dmoead](algorithms/algorithms.base.dmoo.dmoead.md)
- [dmoeadde](algorithms/algorithms.base.dmoo.dmoeadde.md)

## Classic Response Mechanisms

- [nsga2_ae](algorithms/algorithms.classic.nsga2_ae.md)
- [nsga2_pps](algorithms/algorithms.classic.nsga2_pps.md)
- [moeadde_svr](algorithms/algorithms.classic.moeadde_svr.md)

## Knowledge-Based Response Mechanisms

- [nsga2_kgb](algorithms/algorithms.knowledge.nsga2_kgb.md)
- [nsga2_ktmm](algorithms/algorithms.knowledge.nsga2_ktmm.md)
- [nsga2_imkt](algorithms/algorithms.modern.nsga2_imkt.md)

## Learning-Based Response Mechanisms

- [nsga2_tr](algorithms/algorithms.learning.nsga2_tr.md)
- [nsga2_imkt_lstm](algorithms/algorithms.modern.nsga2_imkt_lstm.md)
- [nsga2_imkt_clstm](algorithms/algorithms.modern.nsga2_imkt_clstm.md)
